@@ -110,8 +110,8 @@ gedit_app_dispose (GObject *object)
 	g_clear_object (&app->priv->window_settings);
 	g_clear_object (&app->priv->settings);
 
-	g_clear_object (app->priv->page_setup);
-	g_clear_object (app->priv->print_settings);
+	g_clear_object (&app->priv->page_setup);
+	g_clear_object (&app->priv->print_settings);
 
 	/* Note that unreffing the extensions will automatically remove
 	   all extensions which in turn will deactivate the extension */
